/*
Copyright (c) 2000                      RIPE NCC


All Rights Reserved

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of the author not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO EVENT SHALL
AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

/*
-------------------------------------------------------------------------------
Module Header
Filename          : TTMDataChain.h
Author            : Rene Wilhelm
Date              : 13-OCT-2000
Description       : TTMDataChain class definition (create chain of
                    ROOT TTree files for specific measurement period)
Language Version  : C++
OSs Tested        : Solaris 2.6
$Id: TTMDataChain.h,v 1.3 2000/10/13 13:36:08 wilhelm Exp $
-------------------------------------------------------------------------------
*/

#ifndef TTMDataChain_included
#define TTMDataChain_included

#include <time.h>
#include <TChain.h> 		// ROOT TChain class
#include "TestBoxConfig.h"	// TTM  TestBoxConfig class


class TTMDataChain {
private:
	TestBox source;
	TChain *chain;
	char* datapath;
	char  storage;	// 'H' = hierarchical, year/month/day, 'F' = flat
	time_t endtime;
	time_t period;

public:
	TChain* getRootChain() { return chain;}		   // pointer to TChain
	~TTMDataChain();				   // destructor
	TTMDataChain(TestBox source, time_t endtime,
		time_t period, char *path, char storage);  

		// constructor of TTMDataChain object
		//  source - source testbox                  (TestBox object)
		//  endtime - endtime of selected data       (UNIX timestamp)
		//  per - timeperiod of selected data        (seconds)
		//  path - pathname to TTM ROOT datastorage  (char string)
		//  stype - type of datastorage ('H' = year/month/day hierarchy)
};


#endif 

